@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -100,7 +100,8 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         switch ($data->get('adm_ajax')) {
         case 'import':
             $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
-            $context->setViewType('js.ajax');
+            $context->setViewType('js.default');
+            $data->addImport('ajax');
             break;
         case 'json':
             $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
