@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -99,9 +99,27 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             foreach ($this->form->getValues($alias) as $column => $value) {
                 if (is_array($value)) {
                     $in = array();
-                    foreach ($value as $tmp) {
-                        if (($tmp !== null) && ($tmp !== '')) {
-                            $in[] = $tmp;
+                    foreach ($value as $name => $value1) {
+                        // ̾select, checkbox
+                        if (is_int($name)) {
+                            if (($value1 !== null) && ($value1 !== '')) {
+                                $in[] = $value1;
+                            }
+                        // 롼ԥ
+                        } else {
+/*
+                            if (is_array($value1)) {
+                                foreach ($value1 as $value2) {
+                                    if (($value2 !== null) && ($value2 !== '')) {
+                                        $in[] = $value2;
+                                    }
+                                }
+                            } else {
+                                if (($value1 !== null) && ($value1 !== '')) {
+                                    $conditions->addLike($column, '%' . $conn->escapeLike($value1) . '%');
+                                }
+                            }
+*/
                         }
                     }
                     if (count($in) > 0) {
@@ -124,7 +142,6 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             $tables[$alias] =& $table;
         }
 
-
         // ڡ󥻥å
         $this->dao->setPage($page, $limit);
         // ɽǡ
@@ -132,14 +149,24 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
 
         // ץɽ̾Ѵ
         $options = array();
+        $display_limits = array();
         foreach (array_keys($this->dao->getSelectHeaders()) as $name) {
             $options[$name] = $this->form->getOption($name);
+            $element_config = $this->form->getConfig($name);
+            $display_limits[$name] = (isset($element_config['display_limit_list']) && is_numeric($element_config['display_limit_list']))
+                                   ? $element_config['display_limit_list']
+                                   : null;
         }
 
         $cnt = count($results);
         for ($i=0; $i<$cnt; $i++) {
             // ꥪץ̾Ѵ
             foreach ($results[$i] as $name => $value) {
+                if ($display_limits[$name] !== null) {
+                    if (mb_strlen($results[$i][$name]) > $display_limits[$name]) {
+                        $results[$i][$name] = mb_substr($results[$i][$name], 0, $display_limits[$name], SYL_ENCODE_INTERNAL) . '...';
+                    }
+                }
                 if ($options[$name] !== null) {
                     // ͤ
                     $this->option_values[$i][$name] = $results[$i][$name];
@@ -155,7 +182,6 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
                 $results[$i][$name] = $results[$i][$data_source['name']];
             }
         }
-
         return $results;
     }
 
@@ -172,9 +198,27 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         foreach (array_keys($this->tables) as $alias) {
             foreach ($this->form->getValues($alias) as $column => $value) {
                 if (is_array($value)) {
-                    foreach ($value as $tmp) {
-                        if (($tmp !== null) && ($tmp !== '')) {
-                            $search_parameters[] = $column . '[]=' . urlencode($tmp);
+                    foreach ($value as $column1 => $value1) {
+                        // ̾select, checkbox
+                        if (is_int($column1)) {
+                            if (($value1 !== null) && ($value1 !== '')) {
+                                $search_parameters[] = $column . '[]=' . urlencode($value1);
+                            }
+                        // 롼ԥ
+                        } else {
+/*
+                            if (is_array($value1)) {
+                                foreach ($value1 as $value2) {
+                                    if (($value2 !== null) && ($value2 !== '')) {
+                                        $search_parameters[] = $column1 . '[]=' . urlencode($value2);
+                                    }
+                                }
+                            } else {
+                                if (($value1 !== null) && ($value1 !== '')) {
+                                    $search_parameters[] = $column1 . '=' . urlencode($value1);
+                                }
+                            }
+*/
                         }
                     }
                 } else {
