@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.7 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -49,7 +49,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Xml/Rpc/SyL_XmlRpcServerReader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.7 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataXmlrpc extends SyL_DataWeb
@@ -95,7 +95,7 @@ class SyL_DataXmlrpc extends SyL_DataWeb
      */
     function finalOutputs()
     {
-        $parameters = $this->gets();
+        $parameters = $this->gets(false);
         $this->deletes();
         return $parameters;
     }
