@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.10 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.10 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.11 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -136,29 +136,54 @@ class SyL_ActionForm extends SyL_Form
     {
         // Ͽ롼
         foreach ($this->elements_config as $name => $values) {
-            $type         = $values['type'];
-            $display_name = isset($values['name'])       ? $values['name']       : $name;
-            $options      = isset($values['options'])    ? $values['options']    : array();
-            $attributes   = isset($values['attributes']) ? $values['attributes'] : array();
             // Ǻ
-            $element =& $this->createElement($type, $name, $display_name, $options, $attributes);
+            $element =& $this->createElement($name, $values);
             // Ƚ
             if ($init && isset($values['default'])) {
                 $element->setValue($values['default']);
             }
+            // Хǡɲ
             if (isset($values['validate']) && (count($values['validate']) > 0)) {
-                // Хǡɲ
-                $vs =& SyL_Validators::create();
-                foreach ($values['validate'] as $v_name => $v_values) {
-                    $v_parameters = isset($v_values['parameters']) ? $v_values['parameters'] : array();
-                    $vs->add(SyL_Validator::create($v_name, $v_values['message'], $v_parameters));
-                }
-                $element->setValidators($vs);
+                $this->setElementValidations($element, $values);
             }
             $this->addElement($element);
         }
     }
 
+    /**
+     * Ǥ
+     *
+     * @access public
+     * @param string ̾
+     * @param array °
+     */
+    function &createElement($name, $values)
+    {
+        $type         = $values['type'];
+        $display_name = isset($values['name'])       ? $values['name']       : $name;
+        $options      = isset($values['options'])    ? $values['options']    : array();
+        $attributes   = isset($values['attributes']) ? $values['attributes'] : array();
+        return parent::createElement($type, $name, $display_name, $options, $attributes);
+    }
+
+    /**
+     * Ǥ˥Хǡ򥻥åȤ
+     *
+     * @access public
+     * @param object ǥ֥
+     * @param array °
+     */
+    function setElementValidations(&$element, $values)
+    {
+        // Хǡɲ
+        $vs =& SyL_Validators::create();
+        foreach ($values['validate'] as $v_name => $v_values) {
+            $v_parameters = isset($v_values['parameters']) ? $v_values['parameters'] : array();
+            $vs->add(SyL_Validator::create($v_name, $v_values['message'], $v_parameters));
+        }
+        $element->setValidators($vs);
+    }
+
     /**
      * եǤǼ
      *
