@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.7 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.7 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -165,25 +165,29 @@ class SyL_Data extends SyL_UtilProperty
      * ץѥƥ
      * 
      * @access public
+     * @param bool ѥ᡼ե饰
      * @return array ץѥƥ
      */
-    function gets()
+    function gets($init_param=true)
     {
-        return parent::gets() + $this->input_parameters;
+        return ($init_param) ? parent::gets() + $this->input_parameters : parent::gets();
     }
 
     /**
      * ץѥƥʻȡ
      * 
      * @access public
+     * @param bool ѥ᡼ե饰
      * @return array ץѥƥ
      */
-    function &getsRef()
+    function &getsRef($init_param=true)
     {
         $values =& parent::getsRef();
-        foreach (array_keys($this->input_parameters) as $name) {
-            if (!isset($values[$name])) {
-                $values[$name] =& $this->input_parameters[$name];
+        if ($init_param) {
+            foreach (array_keys($this->input_parameters) as $name) {
+                if (!isset($values[$name])) {
+                    $values[$name] =& $this->input_parameters[$name];
+                }
             }
         }
         return $values;
